using FitConnect.Interfaces;
using Newtonsoft.Json;

public record MockSettings(List<string> PrivateDecryptionKeys, string PrivateSigningKey,
    string PublicKeyEncryption, string PublicKeySignatureVerification, string SenderClientId,
    string SenderClientSecret, string SubscriberClientId, string SubscriberClientSecret,
    Guid DestinationId, string ServiceIdentifier, string CallbackSecret) : IFitConnectSettings;

public record ConfigFile(
    ClientConfig Sender, ClientConfig Subscriber, string ServiceIdentifier,
    List<DestinationConfig> Destinations);

public record DestinationConfig(Guid Id, List<string> PrivateDecryptionKey, string PrivateSigningKey, string PublicEncryptionKey, string PublicSignatureVerificationKey);

public record ClientConfig(string ClientId, string ClientSecret, string CallbackSecret);


public static class ConfigurationLoader {
    public static IFitConnectSettings? GetSettingsFromFiles() {
        Console.WriteLine("Reading settings from files");
        try {
            var credentials =
                JsonConvert.DeserializeObject<ConfigFile>(
                    File.ReadAllText("./credentials.json"))!;

            var senderClientId = credentials.Sender.ClientId;
            var senderClientSecret = credentials.Sender.ClientSecret;
            var subscriberClientId = credentials.Subscriber.ClientId;
            var subscriberClientSecret = credentials.Subscriber.ClientSecret;
            var serviceIdentifier = credentials.ServiceIdentifier;
            var callbackSecret = credentials.Subscriber.CallbackSecret;
            var destinationId = credentials.Destinations.First().Id.ToString();

            return new MockSettings(
                credentials.Destinations.First().PrivateDecryptionKey,
                credentials.Destinations.First().PrivateSigningKey,
                credentials.Destinations.First().PublicEncryptionKey,
                credentials.Destinations.First().PublicEncryptionKey,
                senderClientId,
                senderClientSecret,
                subscriberClientId,
                subscriberClientSecret,
                Guid.Parse(destinationId),
                serviceIdentifier, callbackSecret);
        }
        catch {
            Console.WriteLine("Files not found, using environment variables");
            return null;
        }
    }

}